@@ -1,23 +1,25 @@
 //! This module provides models that are used in the openlimits-exchange module
 
-mod request;
-mod ask_bid;
-mod balance;
-mod candle;
-mod interval;
-mod liquidity;
-mod order_canceled;
-mod order_filter;
-mod order_status;
-mod order_type;
-mod order;
-mod paginator;
-mod side;
-mod ticker;
-mod time_in_force_visitor;
-mod time_in_force;
-mod trade;
-mod transaction;
+pub mod request;
+pub mod ask_bid;
+pub mod balance;
+pub mod candle;
+pub mod interval;
+pub mod liquidity;
+pub mod order_canceled;
+pub mod order_filter;
+pub mod order_status;
+pub mod order_type;
+pub mod order;
+pub mod paginator;
+pub mod side;
+pub mod ticker;
+pub mod time_in_force_visitor;
+pub mod time_in_force;
+pub mod trade;
+pub mod transaction;
+pub mod currency;
+pub mod market_pair;
 
 pub use request::*;
 pub use ask_bid::AskBid;
